@@ -47,8 +47,8 @@ class Consumer:
                 credentials=creds,
                 heartbeat=int(self.rabbitmq_config["heartbeat_time_s"]),
                 connection_attempts=int(self.rabbitmq_config["conn_retries"]),
-                retry_delay=int(self.rabbitmq_config["conn_retry_delay_s"])
-            ))
+                retry_delay=int(self.rabbitmq_config["conn_retry_delay_s"]),
+                client_properties={"connection_name": "leaf-"+self.rabbitmq_config["leaf_id"]}))
 
         except Exception as e:
             sys.exit("[Consumer] Error while connecting to rabbitmq: " + str(e))
